<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Poll directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2015.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin, Inc.
Custom Field Type:
	Vote Options Field
Name:
	vote_options_render.cfc
Summary:
	Custom field to render multiple input fields for answers for PT Poll questions
	
ADF Requirements:
	application.ptPoll.pollQuestionDAO
History:
	2015-06-26 - GAC - Updated
	2016-02-26 - DRM - Resource detection support
--->

<cfcomponent displayName="voteOptionsRender" extends="commonspot.public.form-field-renderer-base" output="no">

<cffunction name="renderControl" access="public" returnType="void">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="isRequired" type="boolean" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.parameters);
		var currentValue = arguments.value;	// the field's current value
		var readOnly = (arguments.displayMode EQ 'readonly') ? true : false;
		var opts = 0;
		var maxOpts = 20;
		
		// If needed, covert comma-delimited (",") list to pipe-delimited list ("|")
		if ( ListLen(currentValue,",") GT 0 ) 		
			currentValue = ListChangeDelims(currentValue,"|",",");	 
	</cfscript>
	
	<cfscript>
		renderJSFunctions(argumentCollection=arguments, fieldParameters=inputParameters);
		renderStyles(argumentCollection=arguments);
	</cfscript>
	
	<cfoutput>
		<!--- // DIV for option quantity selection field --->
		<div id="voteOptionsContainer_#arguments.fieldName#">
			<label for="voteOptions_#arguments.fieldName#">Select the number of answer options:</label> 
			<select name="voteOptions_#arguments.fieldName#" id="voteOptions_#arguments.fieldName#" size="1">
				<cfloop from=1 to="#maxOpts#" index=opts>
				<option value="#opts#">#opts#</option>
				</cfloop>
			</select>
		</div>
		<!--- // DIV for dynamic option fields --->
		<div id="fieldContainer_#arguments.fieldName#">
			<ol id="voteOptionFields_#arguments.fieldName#">
			</ol>
		</div>
		<!--- // hidden field to store the value --->
		<input type="hidden" name="#arguments.fieldName#" id="#arguments.fieldDomID#" value="#currentValue#">
	</cfoutput>
</cffunction>

<cffunction name="renderStyles" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	
<cfoutput>
<style type="text/css">
##fieldContainer_#arguments.fieldName#{
	margin-left: 2px;
	padding-left: 10px;
}
##voteOptionFields_#arguments.fieldName#{
	/* list-style: none !important; */
	padding: 0 6px 0; 
	margin-left: 3px; 
}
##voteOptionFields_#arguments.fieldName# li{
	padding-top: 2px;
	padding-bottom: 2px;
	background: url() !important;
}
</style></cfoutput>
</cffunction>

<cffunction name="renderJSFunctions" returntype="void" access="private">
	<cfargument name="fieldName" type="string" required="yes">
	<cfargument name="fieldDomID" type="string" required="yes">
	<cfargument name="value" type="string" required="yes">
	<cfargument name="fieldParameters" type="struct" required="yes">
	
	<cfscript>
		var inputParameters = Duplicate(arguments.fieldParameters);
		var currentValue = arguments.value;	// the field's current value

		// If needed, covert comma-delimited (",") list to pipe-delimited list ("|")
		if ( ListLen(currentValue,",") GT 0 ) 		
			currentValue = ListChangeDelims(currentValue,"|",",");
	</cfscript>

<cfoutput>
<script type="text/javascript">
<!--
jQuery(function(){
	// bind onchange to build the options
	jQuery("##voteOptions_#arguments.fieldName#").change(handleAddOptionField_#arguments.fieldName#);
				
	// load the current vote options
	loadOptions_#arguments.fieldName#();
				
	// Update the hidden field with any updated vote options
	jQuery("##voteOptionFields_#arguments.fieldName#").on('keyup','input.optionVal',handleSave_#arguments.fieldName#);
});
			
// handle the changing of the number of options to add
function handleAddOptionField_#arguments.fieldName#()
{
	// get the current value of the field
	var inputs = jQuery("##voteOptions_#arguments.fieldName#").selectedValues()[0];
	// check to see how many are there already
	var curLen = jQuery("##voteOptionFields_#arguments.fieldName#").children().length;
	var count = 0;
	// if we have extra, remove them
	if (curLen > 0 && curLen > inputs) 
	{
		jQuery("##voteOptionFields_#arguments.fieldName#").children().each(function(){
			count++;
			if( count > inputs )
			{
			 	jQuery(this).remove();
			 	handleSave_#arguments.fieldName#();
			}
			// shrink the height of the div
			adjustHeight_#arguments.fieldName#();
		});
	}
	else 
	{
		// iterate and build new textfields
		for (curLen; curLen < inputs; curLen++) {
			addTextField_#arguments.fieldName#("");
			adjustHeight_#arguments.fieldName#();
		}
	}
}
			
// add a new text field into the div
function addTextField_#arguments.fieldName#(textVal)
{
	var txtField = "<li><input type='text' size='50' class='optionVal' value='" + textVal + "' /></li>";
	jQuery("##voteOptionFields_#arguments.fieldName#").append(txtField);
}
			
// loads the current values into the text fields
function loadOptions_#arguments.fieldName#()
{
	// get the current values as an array
	var curVals = '#currentValue#';
	//var vals = jQuery.ListToArray("#currentValue#");
	var vals = curVals.split("|");
				
	// set the selected value and then trigger the select event
	jQuery("##voteOptions_#arguments.fieldName#").selectOptions(vals.length.toString());
			
	// And Input fields
	handleAddOptionField_#arguments.fieldName#();
				
	// fill in the values
	jQuery("##voteOptionFields_#arguments.fieldName#").children().each(function(i){
		jQuery(this).children("input").val(vals[i]);
	});
}
			
// called when the custom element form is submitted
function handleSave_#arguments.fieldName#()
{
	var rtnStr = "";
	var i = 0;
	// loop through the children fields and repackage their data for storage
	jQuery("##voteOptionFields_#arguments.fieldName#").children().children("input").each(function(i){
		if (i == 0)
			rtnStr =  jQuery.trim(jQuery(this).val());
		else
			rtnStr = rtnStr + "|" + jQuery.trim(jQuery(this).val());
		// store the new value into the hidden field
		jQuery("input[name=#arguments.fieldName#]").val(rtnStr);
	});
	return true;
}
		
// handles adjusting the height
function adjustHeight_#arguments.fieldName#()
{
	// Not needed when added the ResizeWindow() 
	//jQuery("##fieldContainer_#arguments.fieldName#").height( ((jQuery("##voteOptionFields_#arguments.fieldName#").children().length * 75)/2) );
	
	ResizeWindow();	
}
//-->
</script></cfoutput>
</cffunction>

<cfscript>
	private boolean function isMultiline()
	{
		return true;
	}
	
	private any function getValidationJS(required string formName, required string fieldName, required boolean isRequired)
	{
		if (arguments.isRequired)
			return 'hasValue(document.#arguments.formName#.#arguments.fieldName#, "TEXT")';
		return "";
	}
	
	private string function getValidationMsg()
	{
		return "Please enter at least one question in the #arguments.label# fields.";
	}


	public string function getResourceDependencies()
	{
		return listAppend(super.getResourceDependencies(), "jQuery,JQuerySelectboxes");
	}
	public string function loadResourceDependencies()
	{
		application.ptPoll.scripts.loadJQuery();
		application.ptPoll.scripts.loadJQuerySelectboxes();
	}
</cfscript>

</cfcomponent>